#
# spec file for package disruptor
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           disruptor
Version:        3.4.4
Release:        2.8
Summary:        Concurrent Programming Framework
License:        Apache-2.0
URL:            https://lmax-exchange.github.io/disruptor/
Source0:        https://github.com/LMAX-Exchange/disruptor/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        https://repo1.maven.org/maven2/com/lmax/%{name}/%{version}/%{name}-%{version}.pom
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.hamcrest:hamcrest-library)
BuildArch:      noarch

%description
A High Performance Inter-Thread Messaging Library.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q
# Cleanup
find . -name "*.class" -print -delete
find . -name "*.jar" -type f -print -delete

cp -p %{SOURCE1} pom.xml

# Add OSGi support
%pom_xpath_inject "pom:project" "<packaging>bundle</packaging>"
%pom_add_plugin org.apache.felix:maven-bundle-plugin:2.3.7 . '
<extensions>true</extensions>
<configuration>
  <instructions>
    <Bundle-DocURL>%{url}</Bundle-DocURL>
    <Bundle-Name>${project.name}</Bundle-Name>
    <Bundle-Vendor>LMAX Disruptor Development Team</Bundle-Vendor>
  </instructions>
</configuration>
<executions>
  <execution>
    <id>bundle-manifest</id>
    <phase>process-classes</phase>
    <goals>
      <goal>manifest</goal>
    </goals>
  </execution>
</executions>'

%{mvn_file} :%{name} %{name}

%build

%{mvn_build} -f -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
    -Dproject.build.sourceEncoding=UTF-8 -Dmaven.compiler.source=1.8 -Dmaven.compiler.target=1.8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%doc README.md
%license LICENCE.txt

%files javadoc -f .mfiles-javadoc
%license LICENCE.txt

%changelog
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Fri Dec 10 2021 Pedro Monreal <pmonreal@suse.com>
- Update to 3.4.4:
  * 3.4.4 Lazy-loading of Logger instances - See #370 & #376
  * 3.4.3 Add Automatic-Module-Name to MANIFEST.MF
  * 3.4.2 Fix race condition in BatchEventProcessor with 3 or more
    starting/halting concurrently.
  * 3.4.1 Fix race between run() and halt() on BatchEventProcessor.
  * 3.4.0 Drop support for JDK6, support JDK7 and above only.
    Add ThreadHints.onSpinWait to all busy spins within Disruptor.
    Increase default sleep time for LockSupport.parkNanos to
    prevent busy spinning.
  * 3.3.8 Revert belt and braces WaitStrategy signalling.
  * 3.3.7 Add batch size to BatchStartAware.onBatchStart()
    Upgrade to newer versions of gradle, checkstyle and JUnit
    Deprecate classes & methods for later release
    Remove JMock and rewrite tests accordingly
- Remove disruptor-3.3.2-jmock.patch
* Tue Oct  1 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of disruptor 3.3.6
